from django.contrib import admin
from documents.models import Page, Document, DocumentLink, Section, Transcription
from enumfields.admin import EnumFieldListFilter


class PageAdmin(admin.ModelAdmin):
    list_display = ('id', 'name', 'page_type', 'nb', 'direction', )
    list_filter = [('page_type', EnumFieldListFilter)]
    fields = ('id', 'name', 'folio', 'page_type', 'nb', 'direction', 'image')
    readonly_fields = ('id', )


class DocumentLinkAdmin(admin.TabularInline):
    model = DocumentLink
    fk_name = 'parent'
    raw_id_fields = ('child', )


class DocumentAdmin(admin.ModelAdmin):
    list_display = ('id', 'name', 'type')
    list_filter = [('type', EnumFieldListFilter)]
    fields = ('id', 'type', 'name')
    readonly_fields = ('id', )
    inlines = [DocumentLinkAdmin, ]


class SectionAdmin(admin.ModelAdmin):
    list_display = ('id', 'name')
    fields = ('id', 'name')
    readonly_fields = ('id', )


class TranscriptionAdmin(admin.ModelAdmin):
    list_display = ('id', 'line', 'text', 'score')
    fields = ('id', 'zone', 'line', 'text', 'score')
    readonly_fields = ('id', )
    raw_id_fields = ('zone', )


admin.site.register(Page, PageAdmin)
admin.site.register(Document, DocumentAdmin)
admin.site.register(Section, SectionAdmin)
admin.site.register(Transcription, TranscriptionAdmin)
