from rest_framework.generics import ListAPIView
from documents.serializers import DocumentSerializer, PageSerializer, PageLightSerializer
from documents.models import Document, DocumentType, Page
from documents.search import search_pages
from functools import lru_cache


class DocumentsList(ListAPIView):
    """
    List documents using pagination
    """
    serializer_class = DocumentSerializer

    def get_queryset(self):

        # Apply filters
        documents = Document.objects.filter(
            type=self.request.query_params.get('type', DocumentType.Volume)
        )

        return documents


class RelatedDocumentsList(ListAPIView):
    """
    List all documents linked to a specified document
    """
    serializer_class = DocumentSerializer

    def get_queryset(self):
        return Document.objects.filter(
            id__in=Document.objects.get_related(self.kwargs['pk'])
        )


class DocumentPages(ListAPIView):
    """
    List pages inside a document
    """
    serializer_class = PageLightSerializer

    def get_queryset(self):
        return Page.objects.filter(document=self.kwargs['pk'])


class PagesSearch(ListAPIView):
    """
    Search and list pages, using pagination
    """
    serializer_class = PageSerializer

    @lru_cache(maxsize=10)
    def get_queryset(self):
        # Search using indexed words
        query = self.request.query_params.get('q')
        if query:
            return search_pages(query)

        # Fallback
        return Page.objects.all()
