from django.db import models, connection


class DocumentManager(models.Manager):
    """Model manager for documents"""

    def get_ascending(self, id):
        """Get all parent IDs for a specific document ID."""
        with connection.cursor() as cursor:
            cursor.execute(
                "SELECT parent_id FROM documents_parents WHERE id = %s", [id])
            return [row[0] for row in cursor.fetchall()]

    def get_descending(self, id):
        """Get all child IDs for a specific document ID."""
        with connection.cursor() as cursor:
            cursor.execute(
                "SELECT child_id FROM documents_children WHERE id = %s", [id])
            return [row[0] for row in cursor.fetchall()]

    def get_related(self, id):
        """Get all parent or child IDs for a specific document ID."""
        with connection.cursor() as cursor:
            cursor.execute(
                """
                SELECT parent_id FROM documents_parents WHERE id = %s
                    UNION
                SELECT child_id FROM documents_children WHERE id = %s
                """, [id, id])
            return [row[0] for row in cursor.fetchall()]
