from rest_framework import serializers
from documents.models import Document, Transcription, Page
from images.serializers import ImageSerializer, ZoneSerializer


class EnumField(serializers.Field):
    """
    Serializes an enum field into a JSON value
    """

    def to_representation(self, obj):
        return obj.value

    def to_internal_value(self, data):
        # TODO !
        return


class TranscriptionSerializer(serializers.ModelSerializer):
    """
    Serialises a Transcription
    issued from a search
    """
    class Meta:
        model = Transcription
        fields = (
            'id',
            'text',
            'line',
            'score',
        )


class SearchResultSerializer(serializers.Serializer):
    """
    Link between objects & their search indexation
    """
    transcriptions = TranscriptionSerializer(many=True)
    zone = ZoneSerializer()


class DocumentLightSerializer(serializers.ModelSerializer):
    """
    Serialises a Document
    """
    type = EnumField()

    class Meta:
        model = Document
        fields = (
            'id',
            'type',
            'name',
        )


class PageLightSerializer(serializers.ModelSerializer):
    """
    Serialises a Page
    """
    page_type = EnumField()
    direction = EnumField()
    image = ImageSerializer()

    class Meta:
        model = Page
        fields = (
            'id',
            'page_type',
            'nb',
            'direction',
            'image',
        )


class PageSerializer(serializers.ModelSerializer):
    """
    Serialises a Page, for search results
    """
    indexes = SearchResultSerializer(many=True)
    page_type = EnumField()
    direction = EnumField()
    image = ImageSerializer()

    class Meta:
        model = Page
        fields = (
            'id',
            'page_type',
            'nb',
            'direction',
            'image',
            'indexes',
        )


class DocumentSerializer(serializers.ModelSerializer):
    """
    Fully Serialises a document
    * needs nb_pages from aggregation
    """
    type = EnumField()

    class Meta:
        model = Document
        fields = (
            'id',
            'type',
            'name',
        )
