from django.test import TestCase
from documents.models import Document, DocumentLink, DocumentType


class TestDocumentManager(TestCase):
    """Tests for DocumentManager class"""

    def setUp(self):
        self.reg = Document.objects.create(name="Register", type=DocumentType.Register)
        self.vol = Document.objects.create(name="Volume", type=DocumentType.Volume)
        self.p1 = Document.objects.create(name="Page1", type=DocumentType.Page)
        self.p2 = Document.objects.create(name="Page2", type=DocumentType.Page)
        self.act = Document.objects.create(name="Act", type=DocumentType.Act)
        # Register --> Volume --> [Page1 --> Act, Page2]
        DocumentLink.objects.create(parent=self.reg, child=self.vol, order=0)
        DocumentLink.objects.create(parent=self.vol, child=self.p1, order=0)
        DocumentLink.objects.create(parent=self.vol, child=self.p2, order=1)
        DocumentLink.objects.create(parent=self.p1, child=self.act, order=0)

    def test_get_ascending(self):
        # Use Page1, expect Register and Volume
        ids = Document.objects.get_ascending(self.p1.id)
        self.assertCountEqual(ids, [self.reg.id, self.vol.id])

    def test_get_ascending_empty(self):
        # Use Register, expect empty list
        ids = Document.objects.get_ascending(self.reg.id)
        self.assertCountEqual(ids, [])

    def test_get_descending(self):
        # Use Volume, expect Page1, Page2 and Act
        ids = Document.objects.get_descending(self.vol.id)
        self.assertCountEqual(ids, [self.p1.id, self.p2.id, self.act.id])

    def test_get_descending_empty(self):
        # Use Page2, expect empty list
        ids = Document.objects.get_descending(self.p2.id)
        self.assertCountEqual(ids, [])

    def test_get_related(self):
        # Use Page1, expect Register, Volume and Act
        ids = Document.objects.get_related(self.p1.id)
        self.assertCountEqual(ids, [self.reg.id, self.vol.id, self.act.id])

    def test_get_related_empty(self):
        # Use a document linked to nothing, expect empty list
        alone = Document.objects.create(name="LonelyPage", type=DocumentType.Page)
        ids = Document.objects.get_related(alone.id)
        self.assertCountEqual(ids, [])
